tonalanalysistools.RootedChordClass
===================================

.. abjad-lineage:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass

.. autoclass:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.bass
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.cardinality
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.cardinality_to_extent
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.chord_quality
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.copy
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.difference
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.extent
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.extent_to_cardinality
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.extent_to_extent_name
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.figured_bass
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.from_selection
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.intersection
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.inversion
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.invert
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.is_transposed_subset
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.is_transposed_superset
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.isdisjoint
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.issubset
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.issuperset
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.item_class
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.items
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.markup
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.multiply
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.order_by
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.quality_pair
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.root
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.root_string
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.symmetric_difference
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.transpose
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.union
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__and__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__contains__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__eq__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__format__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__ge__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__gt__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__hash__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__iter__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__le__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__len__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__lt__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__ne__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__or__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__repr__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__str__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__sub__
      ~abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__xor__

Bases
-----

- :py:class:`pitchtools.PitchClassSet <abjad.tools.pitchtools.PitchClassSet.PitchClassSet>`

- :py:class:`pitchtools.Set <abjad.tools.pitchtools.Set.Set>`

- :py:class:`datastructuretools.TypedFrozenset <abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.bass
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.cardinality
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.chord_quality
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.extent
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.figured_bass
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.inversion
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.item_class
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.items
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.markup
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.quality_pair
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.root
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.root_string
   :noindex:

Methods
-------

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.copy
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.difference
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.intersection
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.invert
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.is_transposed_subset
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.is_transposed_superset
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.isdisjoint
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.issubset
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.issuperset
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.multiply
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.order_by
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.symmetric_difference
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.transpose
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.union
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.from_selection
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.cardinality_to_extent
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.extent_to_cardinality
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.extent_to_extent_name
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__and__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__contains__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__format__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__ge__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__gt__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__hash__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__iter__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__le__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__len__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__lt__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__or__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__repr__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__str__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__sub__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootedChordClass.RootedChordClass.__xor__
   :noindex:
